Changelog
---------

0.3.0 (2015-06-09)
^^^^^^^^^^^^^^^^^^

- Migrated from PyQt to PySide to allow a simpler installation of Qt
  ARMSim.
- Developed a new source code editor based on QPlainTextEdit, though
  removing the prior QScintilla dependency, which allows a simpler
  installation of Qt ARMSim.
- Improved the ARM Assembler syntax highlighting.


0.2.7 (2014-11-05)
^^^^^^^^^^^^^^^^^^

- Last revision of the first functional Qt ARMSim version, as it was
  used on the first semester of an introductory course on Computer
  Architecture at Jaume I University. This version has PyQt and
  QScintilla dependencies.
